@@ -1,9 +1,9 @@
-smc <-
-function(data)
+
+smc <- function(data)
 {
   are.na = FALSE
   coeffs = data.frame(matrix(ncol = ncol(data)))
-  
+
   for(i_dep in names(data))
   {
     dummy.data.frame = data.frame(matrix(ncol = length(names(data)), nrow = 1))
@@ -24,16 +24,16 @@ function(data)
       print("We recommend that you discard one of them.")
       print("Use 'check.correlation()' to find the correlated variables")
   }
-  
+
   mult.corr.coeff = NULL
-  
+
   for(i_dep in rownames(coeffs))
   {
     r = mcc(data[,-which(names(data) == i_dep)], data[,which(names(data) == i_dep)], coeffs[i_dep,]  )
-    
+
     mult.corr.coeff = c(mult.corr.coeff, r)
   }
-  
+
   return(mult.corr.coeff)
-  
+
 }
